@@ -20,6 +20,7 @@ class LocationSetBase:
         self.fews_config_path = fews_config_path
         self._fews_config = fews_config
         self._geo_df = None
+        self._geo_df_original = None
         self._general_location_sets_dict = None
         self._csvfile_meta = None
         self._attrib_files = None
@@ -59,6 +60,14 @@ class LocationSetBase:
         assert isinstance(self._geo_df, gpd.GeoDataFrame)
         return self._geo_df
 
+    @property
+    def geo_df_original(self) -> gpd.GeoDataFrame:
+        if self._geo_df is not None:
+            return self._geo_df
+        self._geo_df = self.fews_config.get_locations(location_set_key=self.fews_name)
+        assert isinstance(self._geo_df, gpd.GeoDataFrame)
+        return self._geo_df
+
     @property
     def general_location_sets_dict(self) -> Dict:
         if self._general_location_sets_dict is not None:
