@@ -8,6 +8,10 @@ class HoofdLocTypeChoices(Enum):
     peilschaal = "peilschaal"
     hoofdlocatie = "hoofdlocatie"
 
+    @classmethod
+    def get_all(cls):
+        return [x.value for x in cls.__members__.values()]
+
 
 class HoofdLocationSet(LocationSetBase):
     @property
@@ -29,16 +33,7 @@ class HoofdLocationSet(LocationSetBase):
     @property
     def validation_rules(self):
         return [
-            {
-                "parameter": "H.S.",
-                "extreme_values": {"hmax": "HS1_HMAX", "hmin": "HS1_HMIN"},
-            },
-            {
-                "parameter": "H2.S.",
-                "extreme_values": {"hmax": "HS2_HMAX", "hmin": "HS2_HMIN"},
-            },
-            {
-                "parameter": "H3.S.",
-                "extreme_values": {"hmax": "HS3_HMAX", "hmin": "HS3_HMIN"},
-            },
+            {"parameter": "H.S.", "extreme_values": {"hmax": "HS1_HMAX", "hmin": "HS1_HMIN"},},
+            {"parameter": "H2.S.", "extreme_values": {"hmax": "HS2_HMAX", "hmin": "HS2_HMIN"},},
+            {"parameter": "H3.S.", "extreme_values": {"hmax": "HS3_HMAX", "hmin": "HS3_HMIN"},},
         ]
